@@ -6,10 +6,11 @@ from method.configuration import Configuration
 
 PaymentStatusesLiterals = Literal[
     'pending',
-    'sent',
     'canceled',
-    'returned',
-    'error'
+    'processing',
+    'failed',
+    'sent',
+    'reversed'
 ]
 
 
@@ -55,7 +56,7 @@ class PaymentResource(Resource):
     def list(self) -> List[Payment]:
         return super(PaymentResource, self)._list(None)
 
-    def create(self, opts: PaymentCreateOpts, request_opts: Optional[RequestOpts]) -> Payment:
+    def create(self, opts: PaymentCreateOpts, request_opts: Optional[RequestOpts] = None) -> Payment:
         return super(PaymentResource, self)._create(opts, request_opts)
 
     def delete(self, _id: str) -> Payment:
